==> nivo-0.6.0.tgz: package/es/components/axes/Axes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { motion as motionPropTypes } from '../../PropTypes';
import Axis from './Axis';

var horizontalPositions = ['top', 'bottom'];
var verticalPositions = ['left', 'right'];
var positions = [].concat(horizontalPositions, verticalPositions);

var axisPropType = PropTypes.shape({
    tickSize: PropTypes.number,
    tickPadding: PropTypes.number,
    format: PropTypes.func
});

var Axes = function (_Component) {
    _inherits(Axes, _Component);

    function Axes() {
        _classCallCheck(this, Axes);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Axes.prototype.render = function render() {
        var _props = this.props,
            xScale = _props.xScale,
            yScale = _props.yScale,
            width = _props.width,
            height = _props.height,
            axes = _props.axes,
            theme = _props.theme,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        return React.createElement(
            'g',
            null,
            positions.map(function (position) {
                if (!axes[position]) return null;

                var axis = axes[position];
                if (axis.enabled !== undefined && axis.enabled === false) return null;

                var scale = horizontalPositions.includes(position) ? xScale : yScale;

                return React.createElement(Axis, _extends({
                    theme: theme
                }, axis, {
                    key: position,
                    width: width,
                    height: height,
                    position: position,
                    scale: scale,
                    animate: animate,
                    motionDamping: motionDamping,
                    motionStiffness: motionStiffness
                }));
            })
        );
    };

    return Axes;
}(Component);

Axes.propTypes = _extends({
    xScale: PropTypes.func.isRequired,
    yScale: PropTypes.func.isRequired,

    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,

    axes: PropTypes.shape({
        top: axisPropType,
        right: axisPropType,
        bottom: axisPropType,
        left: axisPropType
    }).isRequired,

    theme: PropTypes.object.isRequired

}, motionPropTypes);
Axes.defaultProps = {};
export default Axes;

==> nivo-0.7.0.tgz: package/es/components/axes/Axes.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { motionPropTypes } from '../../props';
import Axis from './Axis';

var horizontalPositions = ['top', 'bottom'];
var verticalPositions = ['left', 'right'];
var positions = [].concat(horizontalPositions, verticalPositions);

var axisPropType = PropTypes.shape({
    tickSize: PropTypes.number,
    tickPadding: PropTypes.number,
    format: PropTypes.func
});

var Axes = function (_Component) {
    _inherits(Axes, _Component);

    function Axes() {
        _classCallCheck(this, Axes);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Axes.prototype.render = function render() {
        var _props = this.props,
            xScale = _props.xScale,
            yScale = _props.yScale,
            width = _props.width,
            height = _props.height,
            axes = _props.axes,
            theme = _props.theme,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        return React.createElement(
            'g',
            null,
            positions.map(function (position) {
                if (!axes[position]) return null;

                var axis = axes[position];
                if (axis.enabled !== undefined && axis.enabled === false) return null;

                var scale = horizontalPositions.includes(position) ? xScale : yScale;

                return React.createElement(Axis, _extends({
                    theme: theme
                }, axis, {
                    key: position,
                    width: width,
                    height: height,
                    position: position,
                    scale: scale,
                    animate: animate,
                    motionDamping: motionDamping,
                    motionStiffness: motionStiffness
                }));
            })
        );
    };

    return Axes;
}(Component);

Axes.propTypes = _extends({
    xScale: PropTypes.func.isRequired,
    yScale: PropTypes.func.isRequired,

    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,

    axes: PropTypes.shape({
        top: axisPropType,
        right: axisPropType,
        bottom: axisPropType,
        left: axisPropType
    }).isRequired,

    theme: PropTypes.object.isRequired

}, motionPropTypes);
Axes.defaultProps = {};
export default Axes;
